// FileOperationDlg.h
// (c) 2003-2005 exeal

#ifndef _FILE_OPERATION_DLG_H_
#define _FILE_OPERATION_DLG_H_
#include "resource.h"
#include "../Manah/Dialog.h"


namespace Alpha {
	///	t@C실ʃ_CAO
	class CFileOperationDlg : public Manah::Windows::Controls::CFixedIdDialog<IDD_DLG_FILEOPERATION> {
		// RXgN^
	public:
		CFileOperationDlg(UINT nCommandId, const std::wstring& strFilePath);

		// bZ[Wnh
	protected:
		virtual bool	OnCommand(WORD wID, WORD wNotifyCode, HWND hwndCtrl);	// WM_COMMAND
		virtual bool	OnInitDialog(HWND hwndFocus, LPARAM lInitParam);		// WM_INITDIALOG
		virtual void	OnOK();													// IDOK

		// f[^o
	private:
		const UINT		m_nCommandId;
	public:
		std::wstring	m_strFilePath;
	};
}

#endif /* _FILE_OPERATION_DLG_H_ */

/* [EOF] */